@@ -4,7 +4,6 @@ pub mod filter;
 pub mod graft_map;
 pub mod object;
 pub mod page;
-pub mod widget;
 
 pub use annotation::{LineEndingStyle, PdfAnnotation, PdfAnnotationType};
 pub use document::{Encryption, PdfDocument, PdfWriteOptions, Permission};
@@ -12,4 +11,3 @@ pub use filter::PdfFilterOptions;
 pub use graft_map::PdfGraftMap;
 pub use object::PdfObject;
 pub use page::PdfPage;
-pub use widget::PdfWidget;
